@@ -513,15 +513,12 @@ public abstract class BasicCommandlineOptions {
     }
 
     protected final Credentials credentialsparsing(final AdminParser parser) {
-        Credentials auth = null;
-
-        if( ADMIN_PASSWORD != null ) {
-            // use admin password as set in environment
-            auth = new Credentials((String) parser.getOptionValue(this.adminUserOption), ADMIN_PASSWORD);
-        } else {
-            auth = new Credentials((String) parser.getOptionValue(this.adminUserOption), (String) parser.getOptionValue(this.adminPassOption));
+        // prefer password from options
+        String password = (String) parser.getOptionValue(this.adminPassOption);
+        if (null == password && null != ADMIN_PASSWORD) {
+            password = ADMIN_PASSWORD;
         }
-        return auth;
+        return new Credentials((String) parser.getOptionValue(this.adminUserOption), password);
     }
 
     /**
