@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2006 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2010 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -49,8 +49,6 @@
 
 package com.openexchange.admin.rmi.dataobjects;
 
-import java.io.IOException;
-import java.io.ObjectStreamException;
 import java.io.Serializable;
 import java.lang.reflect.Field;
 
@@ -539,7 +537,7 @@ public class UserModuleAccess implements Serializable {
     }
 
     public void setPublicFolderEditable(final boolean publicFolderEditable) {
-        PublicFolderEditable = publicFolderEditable;
+        this.PublicFolderEditable = publicFolderEditable;
     }
 
     @Override
