@@ -52,7 +52,6 @@ import static junit.framework.Assert.assertNotNull;
 import static org.junit.Assert.assertEquals;
 import static org.junit.Assert.assertTrue;
 import static org.junit.Assert.fail;
-
 import java.lang.reflect.Field;
 import java.lang.reflect.Method;
 import java.net.MalformedURLException;
@@ -66,11 +65,8 @@ import java.util.HashSet;
 import java.util.Hashtable;
 import java.util.List;
 import java.util.TimeZone;
-
 import junit.framework.JUnit4TestAdapter;
-
 import org.junit.Test;
-
 import com.openexchange.admin.rmi.dataobjects.Context;
 import com.openexchange.admin.rmi.dataobjects.Credentials;
 import com.openexchange.admin.rmi.dataobjects.User;
@@ -820,6 +816,8 @@ public class UserTest extends AbstractTest {
                     String oldvalue = (String)map_obj.getGetter().invoke(srv_loaded); 
                     if( map_obj.getMethodName().equals("setLanguage") ) {
                         map_obj.getSetter().invoke(tmp_usr, "fr_FR");
+                    } else if(map_obj.getMethodName().toLowerCase().contains("mail")) {
+                        getChangedEmailAddress(oldvalue, "_singlechange");
                     } else {
                         map_obj.getSetter().invoke(tmp_usr, oldvalue+"_singlechange");
                     }
@@ -1591,8 +1589,8 @@ public class UserTest extends AbstractTest {
         // retval.setPrimaryEmail(usr.getPrimaryEmail()+change_suffix);
         //retval.setEmail1(usr.getEmail1()+change_suffix);
         //retval.setDefaultSenderAddress(usr.getPrimaryEmail()+change_suffix);
-        retval.setEmail2(usr.getEmail2()+change_suffix);
-        retval.setEmail3(usr.getEmail3()+change_suffix);
+        retval.setEmail2(getChangedEmailAddress(usr.getEmail2(), change_suffix));
+        retval.setEmail3(getChangedEmailAddress(usr.getEmail3(), change_suffix));
         
         retval.setDisplay_name(usr.getDisplay_name()+change_suffix);
         retval.setGiven_name(usr.getGiven_name()+change_suffix);
@@ -1600,10 +1598,10 @@ public class UserTest extends AbstractTest {
         retval.setLanguage("en_US");
         // new for testing
         
-        final HashSet<String> aliase = usr.getAliases();
+        final HashSet<String> aliases = usr.getAliases();
         final HashSet<String> lAliases = new HashSet<String>();
-        for (final String element : aliase) {
-            lAliases.add(element + "_" + change_suffix);            
+        for (final String element : aliases) {
+            lAliases.add(getChangedEmailAddress(element, change_suffix));            
         }
         lAliases.add(usr.getPrimaryEmail());
         
